﻿using Borepin.Service.Instances;
using Borepin.ViewModel;
using Prism.Mvvm;
using System.Collections.Generic;
using System.Threading.Tasks;
using System.Linq;
using Borepin.Model;
using System.Windows.Input;
using Prism.Commands;
using Prism.Navigation;
using Prism.Services.Dialogs;

namespace Borepin.PageModel
{
    public class ServerListPageModel : BindableBase
    {
        private INavigationService _NavigationService;
        private IDialogService _DialogService;
        private IInstanceService _InstanceService;

        public ServerListPageModel(INavigationService navigationService, IDialogService dialogService, IInstanceService instanceService)
        {
            _NavigationService = navigationService;
            _DialogService = dialogService;
            _InstanceService = instanceService;

            DeleteAllInstancesCommand = new DelegateCommand(DeleteAllInstancesCommandExecuted);
            AddInstancesCommand = new DelegateCommand(AddInstancesCommandExecuted);

            LoadData();
        }

        private async Task<bool> LoadData()
        {
            List<BFFHInstance> list = await _InstanceService.GetBFFHInstances();
            ServerListItemViewModel_List = list.Select(x => new ServerListItemViewModel(x)).ToList();

            return await Task.FromResult(true);
        }

        #region Properties
        private List<ServerListItemViewModel> _ServerListItemViewModel_List;
        public List<ServerListItemViewModel> ServerListItemViewModel_List
        {
            get => _ServerListItemViewModel_List;
            set => SetProperty(ref _ServerListItemViewModel_List, value);
        }
        #endregion

        #region Commands
        private ICommand _DeleteAllInstancesCommand;
        public ICommand DeleteAllInstancesCommand
        {
            get => _DeleteAllInstancesCommand;
            set => SetProperty(ref _DeleteAllInstancesCommand, value);
        }
        private void DeleteAllInstancesCommandExecuted()
        {
            var parameters = new DialogParameters
            {
                { "title", "Remove all Servers" },
                { "message", "Do you really want to remove all known Servers?" }
            };
            _DialogService.ShowDialog("ConfirmDialog", parameters, DeleteAllInstancesConfirm);
        }

        private void DeleteAllInstancesConfirm(IDialogResult result)
        {
            if (result.Parameters.ContainsKey("confirm"))
            {
                _InstanceService.RemoveAllBFFHInstances();
            }
        }

        private ICommand _AddInstancesCommand;
        public ICommand AddInstancesCommand
        {
            get => _AddInstancesCommand;
            set => SetProperty(ref _AddInstancesCommand, value);
        }

        private async void AddInstancesCommandExecuted()
        {
            INavigationResult result = await _NavigationService.NavigateAsync("HostSelectPage");
            if (!result.Success)
            {
                System.Diagnostics.Debugger.Break();
            }
        }
        #endregion
    }
}
